@@ -29,7 +29,7 @@ def locale_dir():
     return os.path.abspath(os.path.join(os.path.dirname(__file__), "locale"))
 
 
-IS_VIRTUALENV = hasattr(sys, "real_prefix") or (hasattr(sys, "base_prefix") and sys.base_prefix != sys.prefix)
+IS_VIRTUALENV = hasattr(sys, "real_prefix") or (hasattr(sys, "base_prefix") and sys.base_prefix != sys.prefix) or os.getenv("VIRTUAL_ENV")
 
 
 def setup_gettext(language: str = None) -> None:
@@ -161,7 +161,7 @@ def check_req_installed():
     # get the packages string from poetry
     result, output = subprocess.getstatusoutput(f"cd {pyproject_path.parent} && {sys.executable} -m poetry export -f requirements.txt --without-hashes")
 
-    output = clean_output()
+    output = clean_output(output)
     output = output.strip().splitlines()
 
     # Synology remove existing upto date packages from update lists
@@ -405,6 +405,9 @@ def make_virtualenv_and_rerun(location: Path) -> None:
                     # add original arguments to this re-call
                     new_argv = [str(place)] + sys.argv
 
+                    if "VIRTUAL_ENV" not in os.environ:
+                        os.environ["VIRTUAL_ENV"] = str(location)
+
                     logger.info(f"Restarting SickChill with {new_argv}")
                     return os.execvp(new_argv[0], new_argv)
 
