@@ -1,11 +1,14 @@
 #
-# Uses the Synology Download Station API: http://download.synology.com/download/Document/DeveloperGuide/Synology_Download_Station_Web_API.pdf
-import os
+# Uses the Synology Download Station API:
+# http://download.synology.com/download/Document/DeveloperGuide/Synology_Download_Station_Web_API.pdf
+
 import re
+from json import JSONDecodeError
 from urllib.parse import unquote, urljoin
 
 from sickchill import logger, settings
 from sickchill.oldbeard.clients.generic import GenericClient
+from sickchill.providers.GenericProvider import GenericProvider
 
 
 class Client(GenericClient):
@@ -25,6 +28,7 @@ class Client(GenericClient):
         self.urls = {
             "login": urljoin(self.host, "webapi/auth.cgi"),
             "task": urljoin(self.host, "webapi/entry.cgi"),
+            "info": urljoin(self.host, "webapi/DownloadStation/info.cgi"),
         }
 
         self.url = self.urls["task"]
@@ -69,48 +73,6 @@ class Client(GenericClient):
             "session": "DownloadStation",
         }
 
-    def _check_response(self, data=None, files=None):
-        """
-        Checks the response from Download Station, and logs any errors
-        params: :data: post data sent in the original request, in case we need to send it with adjusted parameters
-                :file: file data being sent with the post request, if any
-        """
-        try:
-            jdata = self.response.json()
-        except (ValueError, AttributeError):
-            logger.info("Could not convert response to json, check the host:port: {0!r}".format(self.response))
-            return False
-
-        if not jdata.get("success"):
-            error_code = jdata.get("error", {}).get("code")
-            if error_code == 403:
-                destination = (data or {}).get("destination")
-                if destination and os.path.isabs(destination):
-                    data["destination"] = re.sub(r"^/volume\d/", "", destination).lstrip("/")
-                    self._request(method="post", data=data, files=files)
-
-                    try:
-                        jdata = self.response.json()
-                    except ValueError:
-                        return False
-
-                    if jdata.get("success"):
-                        if destination == settings.SYNOLOGY_DSM_PATH:
-                            settings.SYNOLOGY_DSM_PATH = data["destination"]
-                        elif destination == settings.TORRENT_PATH:
-                            settings.TORRENT_PATH = data["destination"]
-
-        if not jdata.get("success"):
-            error_code = jdata.get("error", {}).get("code")
-            api_method = (data or {}).get("method", "login")
-            log_string = self.error_map.get(api_method).get(error_code, None)
-            if not log_string:
-                logger.info(jdata)
-            else:
-                logger.info("{0}".format(log_string))
-
-        return jdata.get("success")
-
     def _get_auth(self):
         """
         Authenticates the session with DownloadStation
@@ -133,11 +95,84 @@ class Client(GenericClient):
         self.auth = self._check_response()
         return self.auth
 
+    def _check_response(self, data=None):
+        """
+        Checks the response from Download Station, and logs any errors
+        params: :data: post data sent in the original request, in case we need to send it with adjusted parameters
+                :file: file data being sent with the post request, if any
+        """
+        try:
+            jdata = self.response.json()
+        except (ValueError, AttributeError):
+            logger.info("Could not convert response to json, check the host:port: {0!r}".format(self.response))
+            return False
+
+        if not jdata.get("success"):
+            error_code = jdata.get("error", {}).get("code")
+            api_method = (data or {}).get("method", "login")
+            log_string = self.error_map.get(api_method).get(error_code, None)
+            if not log_string:
+                logger.info(jdata)
+            else:
+                logger.info("{0}".format(log_string))
+
+        return jdata.get("success")
+
+    def _get_destination(self, result):
+        """
+        Determines which destination setting to use depending on result type
+        """
+        if result.resultType in (GenericProvider.NZB, GenericProvider.NZBDATA):
+            destination = settings.SYNOLOGY_DSM_PATH.strip()
+        elif result.resultType == GenericProvider.TORRENT:
+            destination = settings.TORRENT_PATH.strip()
+        else:
+            raise AttributeError("Invalid result passed to client when getting destination: resultType {}".format(result.resultType))
+
+        return re.sub(r"^/volume\d/", "", destination).lstrip("/")
+
+    def _set_destination(self, result, destination):
+        """
+        Determines which destination setting to use depending on result type and sets it to `destination`
+        params: :destination: DSM share name
+        """
+        destination = destination.strip()
+        if result.resultType in (GenericProvider.NZB, GenericProvider.NZBDATA):
+            settings.SYNOLOGY_DSM_PATH = destination
+        elif result.resultType == GenericProvider.TORRENT:
+            settings.TORRENT_PATH = destination
+        else:
+            raise AttributeError("Invalid result passed to client when setting destination")
+
+    def _check_destination(self, result):
+        """
+        If destination is not set in configuration, grab it from the API
+        params: :result: an object subclassing oldbeard.classes.SearchResult
+        """
+        params = {
+            "api": "SYNO.DownloadStation.Info",
+            "version": "2",
+            "method": "getconfig",
+        }
+
+        if not self._get_destination(result):
+            try:
+                response = self.session.get(self.urls["info"], params=params, verify=False)
+                response_json = response.json()
+                self._set_destination(result, response_json["data"]["default_destination"])
+                logger.info("Destination set to %s", self._get_destination(result))
+            except (ValueError, KeyError, JSONDecodeError) as error:
+                logger.debug("Get DownloadStation default destination error: {0}".format(error))
+                logger.warning("Could not get share destination from DownloadStation for {}, please set it in the settings", result.resultType)
+                raise
+
     def _add_torrent_uri(self, result):
         """
         Sends a magnet, Torrent url or NZB url to DownloadStation
         params: :result: an object subclassing oldbeard.classes.SearchResult
         """
+        self._check_destination(result)
+
         data = self._task_post_data
 
         if "%3A%2F%2F" in result.url:
@@ -146,14 +181,10 @@ class Client(GenericClient):
             data["url"] = result.url
 
         data["type"] = "url"
-        data['create_list'] = "false"
+        data["create_list"] = "false"
+        data["destination"] = self._get_destination(result)
 
-        if result.resultType == "torrent":
-            if settings.TORRENT_PATH:
-                data["destination"] = settings.TORRENT_PATH
-        elif settings.SYNOLOGY_DSM_PATH:
-            data["destination"] = settings.SYNOLOGY_DSM_PATH
-        logger.info(data)
+        logger.info('Posted as url with {} destination "{}"'.format(data["api"], data["destination"]))
         self._request(method="post", data=data)
         return self._check_response(data)
 
@@ -162,26 +193,21 @@ class Client(GenericClient):
         Sends a Torrent file or NZB file to DownloadStation
         params: :result: an object subclassing oldbeard.classes.SearchResult
         """
+        self._check_destination(result)
+
         data = self._task_post_data
 
         result_type = result.resultType.replace("data", "")
+        files = {result_type: (".".join([result.name, result_type]), result.content)}
 
         data["type"] = '"file"'
         data["file"] = f'["{result_type}"]'
-        data['create_list'] = "false"
+        data["create_list"] = "false"
+        data["destination"] = f'"{self._get_destination(result)}"'
 
-        if result.resultType == "torrent":
-            files = {result_type: (result.name + ".torrent", result.content)}
-            if settings.TORRENT_PATH:
-                data["destination"] = f'"{settings.TORRENT_PATH}"'
-        else:
-            files = {result_type: (result.name + ".nzb", result.extraInfo[0])}
-            if settings.SYNOLOGY_DSM_PATH:
-                data["destination"] = f'"{settings.SYNOLOGY_DSM_PATH}"'
-
-        logger.info(data)
+        logger.info("Posted as file with {} destination {}".format(data["api"], data["destination"]))
         self._request(method="post", data=data, files=files)
-        return self._check_response(data, files)
+        return self._check_response(data)
 
     def sendNZB(self, result):
         """
