@@ -87,7 +87,7 @@ def change_https_key(https_key):
     return True
 
 
-def change_unrar_tool(unrar_tool, unar_tool, bsdtar_tool):
+def change_unrar_tool(unrar_tool, unar_tool):
     try:
         rarfile.tool_setup()
     except rarfile.RarCannotExec:
@@ -95,12 +95,10 @@ def change_unrar_tool(unrar_tool, unar_tool, bsdtar_tool):
     else:
         settings.UNAR_TOOL = rarfile.UNRAR_TOOL
         settings.UNAR_TOOL = rarfile.UNAR_TOOL
-        settings.BSDTAR_TOOL = rarfile.BSDTAR_TOOL
         return True
 
     _unrar_tool = rarfile.UNRAR_TOOL
     _unar_tool = rarfile.UNAR_TOOL
-    _bsdtar_tool = rarfile.BSDTAR_TOOL
 
     if unrar_tool and unrar_tool != rarfile.UNRAR_TOOL:
         rarfile.UNRAR_TOOL = unrar_tool
@@ -108,9 +106,6 @@ def change_unrar_tool(unrar_tool, unar_tool, bsdtar_tool):
     if unar_tool and unar_tool != rarfile.UNAR_TOOL:
         rarfile.UNAR_TOOL = unar_tool
 
-    if bsdtar_tool and bsdtar_tool != rarfile.BSDTAR_TOOL:
-        rarfile.BSDTAR_TOOL = bsdtar_tool
-
     try:
         rarfile.tool_setup()
     except rarfile.RarCannotExec:
@@ -118,12 +113,10 @@ def change_unrar_tool(unrar_tool, unar_tool, bsdtar_tool):
     else:
         settings.UNAR_TOOL = rarfile.UNRAR_TOOL
         settings.UNAR_TOOL = rarfile.UNAR_TOOL
-        settings.BSDTAR_TOOL = rarfile.BSDTAR_TOOL
         return True
 
     rarfile.UNRAR_TOOL = _unar_tool
     rarfile.UNAR_TOOL = _unar_tool
-    rarfile.BSDTAR_TOOL = _bsdtar_tool
 
     if platform.system() == "Windows":
         # Look for WinRAR installations
@@ -178,7 +171,6 @@ def change_unrar_tool(unrar_tool, unar_tool, bsdtar_tool):
     # These must always be set to something before returning
     settings.UNRAR_TOOL = rarfile.UNRAR_TOOL = _unrar_tool
     settings.UNAR_TOOL = rarfile.UNAR_TOOL = _unar_tool
-    settings.BSDTAR_TOOL = rarfile.BSDTAR_TOOL = _bsdtar_tool
 
     try:
         rarfile.tool_setup()
@@ -542,7 +534,7 @@ def change_process_automatically(process_automatically):
 
 
 def check_section(cfg, sec):
-    """ Check if INI section exists, if not create it """
+    """Check if INI section exists, if not create it"""
 
     if sec in cfg:
         return True
@@ -648,7 +640,7 @@ def clean_url(url):
 # min_max                                                                      #
 ################################################################################
 def min_max(val, default, low, high):
-    """ Return value forced within range """
+    """Return value forced within range"""
 
     val = try_int(val, default)
 
@@ -1071,7 +1063,7 @@ class ConfigMigrator(object):
 
     # Migration v4: Add default newznab catIDs
     def _migrate_v4(self):
-        """ Update newznab providers so that the category IDs can be set independently via the config """
+        """Update newznab providers so that the category IDs can be set independently via the config"""
 
         new_newznab_data = []
         old_newznab_data = check_setting_str(self.config_obj, "Newznab", "newznab_data")
@@ -1101,7 +1093,7 @@ class ConfigMigrator(object):
 
     # Migration v5: Metadata upgrade
     def _migrate_v5(self):
-        """ Updates metadata values to the new format """
+        """Updates metadata values to the new format"""
 
         """ Quick overview of what the upgrade does:
 
