@@ -2,6 +2,7 @@ import json
 import time
 
 import requests
+from requests.structures import CaseInsensitiveDict
 
 from sickchill import logger, settings
 from sickchill.oldbeard import common
@@ -75,7 +76,7 @@ class Notifier(object):
             "formatted_body": message,
         }
 
-        headers = {"Content-Type": "application/json"}
+        headers = CaseInsensitiveDict({"Content-Type": "application/json"})
         try:
             r = requests.put(url, data=json.dumps(jsonMessage), headers=headers)
             r.raise_for_status()
