@@ -1,6 +1,8 @@
 import re
 from xml.etree import ElementTree
 
+from requests.structures import CaseInsensitiveDict
+
 import sickchill.oldbeard.common
 from sickchill import logger, settings
 from sickchill.oldbeard import common
@@ -9,12 +11,14 @@ from sickchill.oldbeard.helpers import getURL, make_session
 
 class Notifier(object):
     def __init__(self):
-        self.headers = {
-            "X-Plex-Device-Name": "SickChill",
-            "X-Plex-Product": "SickChill Notifier",
-            "X-Plex-Client-Identifier": sickchill.oldbeard.common.USER_AGENT,
-            "X-Plex-Version": "2016.02.10",
-        }
+        self.headers = CaseInsensitiveDict(
+            {
+                "X-Plex-Device-Name": "SickChill",
+                "X-Plex-Product": "SickChill Notifier",
+                "X-Plex-Client-Identifier": sickchill.oldbeard.common.USER_AGENT,
+                "X-Plex-Version": "2016.02.10",
+            }
+        )
         self.session = make_session()
 
     @staticmethod
