@@ -11,9 +11,10 @@ import sickchill.oldbeard.subtitles
 from sickchill import adba, logger, settings
 from sickchill.helper.common import remove_extension, replace_extension, SUBTITLE_EXTENSIONS
 from sickchill.helper.exceptions import EpisodeNotFoundException, EpisodePostProcessingFailedException, ShowDirectoryNotFoundException
+from sickchill.show.History import History
 from sickchill.show.Show import Show
 
-from . import common, db, failed_history, helpers, history, notifiers, show_name_helpers
+from . import common, db, helpers, notifiers, show_name_helpers
 from .helpers import verify_freespace
 from .name_parser.parser import InvalidNameException, InvalidShowException, NameParser
 
@@ -76,6 +77,8 @@ class PostProcessor(object):
 
         self.anidbEpisode = None
 
+        self.history = History()
+
     def _log(self, message, level=logging.INFO):
         """
         A wrapper for the internal logger which also keeps track of messages and saves them to a string for later.
@@ -1055,8 +1058,8 @@ class PostProcessor(object):
 
         # Just want to keep this consistent for failed handling right now
         releaseName = show_name_helpers.determine_release_name(self.folder_path, self.release_name)
-        if releaseName is not None:
-            failed_history.logSuccess(releaseName)
+        if releaseName:
+            self.history.logSuccess(releaseName)
         else:
             self._log(_("Couldn't find release in snatch history"), logger.WARNING)
 
@@ -1139,7 +1142,7 @@ class PostProcessor(object):
             logger.info(_("Could not create/update meta files. Continuing with postProcessing..."))
 
         # log it to history
-        history.logDownload(ep_obj, self.directory, new_ep_quality, self.release_group, new_ep_version)
+        self.history.logDownload(ep_obj, self.directory, new_ep_quality, self.release_group, new_ep_version)
 
         # If any notification fails, don't stop postProcessor
         try:
