@@ -137,7 +137,7 @@ def determine_release_name(directory=None, release_name=None):
     """Determine a release name from an nzb and/or folder name"""
 
     if release_name is not None:
-        if validators.url(release_name):
+        if validators.url(release_name) == True:
             logger.info(_("Downloader returned a download url rather than a release name"))
             return release_name
 
