@@ -63,7 +63,6 @@ providers = RegistrableExtensionManager(
         "iptorrents = oldbeard.providers.iptorrents:IPTorrentsProvider",
         "torrent9 = oldbeard.providers.torrent9:Torrent9Provider",
         "newpct = oldbeard.providers.newpct:newpctProvider",
-        "gftracker = oldbeard.providers.gftracker:GFTrackerProvider",
         "filelist = oldbeard.providers.filelist:FileListProvider",
         "abnormal = oldbeard.providers.abnormal:ABNormalProvider",
         "torrentproject = oldbeard.providers.torrentproject:TorrentProjectProvider",
@@ -105,11 +104,10 @@ notifiers = RegistrableExtensionManager(
         "rocketchat = oldbeard.notifiers.rocketchat:Notifier",
         "discord = oldbeard.notifiers.discord:Notifier",
         "pushbullet = oldbeard.notifiers.pushbullet:Notifier",
-        "twilio_notify = oldbeard.notifiers.twilio_notify:Notifier",
+        # "twilio_notify = oldbeard.notifiers.twilio_notify:Notifier",
         "tweet = oldbeard.notifiers.tweet:Notifier",
         "synologynotifier = oldbeard.notifiers.synologynotifier:Notifier",
         "plex = oldbeard.notifiers.plex:Notifier",
-        "twilio_notify = oldbeard.notifiers.twilio_notify:Notifier",
         "discord = oldbeard.notifiers.discord:Notifier",
         "freemobile = oldbeard.notifiers.freemobile:Notifier",
         "slack = oldbeard.notifiers.slack:Notifier",
