@@ -1,4 +1,4 @@
-from requests.exceptions import HTTPError
+import requests
 
 from sickchill import logger, settings
 from sickchill.oldbeard import helpers
@@ -12,18 +12,18 @@ def getShowImage(url, imgNum=None):
 
     # if they provided a fanart number try to use it instead
     if imgNum is not None:
-        tempURL = url.split('-')[0] + "-" + str(imgNum) + ".jpg"
+        temp_url = url.split("-")[0] + "-" + str(imgNum) + ".jpg"
     else:
-        tempURL = url
+        temp_url = url
 
-    logger.debug("Fetching image from " + tempURL)
+    logger.debug("Fetching image from " + temp_url)
 
     try:
-        image_data = helpers.getURL(tempURL, session=meta_session, returns='content', allow_proxy=settings.PROXY_INDEXERS)
-    except HTTPError:
+        image_data = helpers.getURL(temp_url, session=meta_session, returns="content", allow_proxy=settings.PROXY_INDEXERS)
+    except requests.exceptions.RequestException:
         image_data = None
 
-    if image_data is None:
+    if not image_data:
         logger.warning("There was an error trying to retrieve the image, aborting")
         return
 
