@@ -154,6 +154,7 @@ FANART_API_KEY = "9b3afaf26f6241bdb57d6cc6bd798da7"
 FANART_BACKGROUND = None
 FANART_BACKGROUND_OPACITY = None
 FILE_TIMESTAMP_TIMEZONE = None
+FLARESOLVERR_URI = ""
 FREEMOBILE_APIKEY = ""
 FREEMOBILE_ID = ""
 FREEMOBILE_NOTIFY_ONDOWNLOAD = False
@@ -545,6 +546,7 @@ USE_TRAKT = False
 USE_TWILIO = False
 USE_TWITTER = False
 USENET_RETENTION = None
+CACHE_RETENTION = 30
 VERSION_NOTIFY = False
 versionCheckScheduler = None
 WEB_COOKIE_SECRET = None
