@@ -13,9 +13,6 @@ from .index import Config
 
 @Route("/config/backuprestore(/?.*)", name="config:backup")
 class ConfigBackupRestore(Config):
-    def __init__(self, *args, **kwargs):
-        super().__init__(*args, **kwargs)
-
     @addslash
     def index(self, *args_, **kwargs_):
         t = PageTemplate(rh=self, filename="config_backuprestore.mako")
