@@ -16,9 +16,6 @@ from .index import Config
 
 @Route("/config/general(/?.*)", name="config:general")
 class ConfigGeneral(Config):
-    def __init__(self, *args, **kwargs):
-        super().__init__(*args, **kwargs)
-
     @addslash
     def index(self):
         t = PageTemplate(rh=self, filename="config_general.mako")
