@@ -14,9 +14,6 @@ from . import Config
 
 @Route("/config/notifications(/?.*)", name="config:notifications")
 class ConfigNotifications(Config):
-    def __init__(self, *args, **kwargs):
-        super().__init__(*args, **kwargs)
-
     @addslash
     def index(self, *args_, **kwargs_):
         t = PageTemplate(rh=self, filename="config_notifications.mako")
