@@ -15,9 +15,6 @@ from . import Config
 
 @Route("/config/postProcessing(/?.*)", name="config:postprocessing")
 class ConfigPostProcessing(Config):
-    def __init__(self, *args, **kwargs):
-        super().__init__(*args, **kwargs)
-
     @addslash
     def index(self, *args_, **kwargs_):
         t = PageTemplate(rh=self, filename="config_postProcessing.mako")
