@@ -12,9 +12,6 @@ from .routes import Route
 
 @Route("/errorlogs(/?.*)", name="logs:error")
 class ErrorLogs(WebRoot):
-    def __init__(self, *args, **kwargs):
-        super().__init__(*args, **kwargs)
-
     def __ErrorLogsMenu(self, level):
         menu = [
             {
